Pnock - knocking ports in pure python
=======================
Quickly finds which hosts are running a server on a given port on your local network.

`The source for this project is available here
<https://github.com/wildarch/pnock>`_.

